==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/OAuthAccessTokenFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OAuthAccessTokenFluent<A extends OAuthAccessTokenFluent<A>> extends BaseFluent<A>{
  public OAuthAccessTokenFluent() {
  }
  
  public OAuthAccessTokenFluent(OAuthAccessToken instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private String authorizeToken;
  private String clientName;
  private Long expiresIn;
  private Integer inactivityTimeoutSeconds;
  private String kind;
  private ObjectMetaBuilder metadata;
  private String redirectURI;
  private String refreshToken;
  private List<String> scopes = new ArrayList<String>();
  private String userName;
  private String userUID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OAuthAccessToken instance) {
    instance = (instance != null ? instance : new OAuthAccessToken());
    if (instance != null) {
          this.withApiVersion(instance.getApiVersion());
          this.withAuthorizeToken(instance.getAuthorizeToken());
          this.withClientName(instance.getClientName());
          this.withExpiresIn(instance.getExpiresIn());
          this.withInactivityTimeoutSeconds(instance.getInactivityTimeoutSeconds());
          this.withKind(instance.getKind());
          this.withMetadata(instance.getMetadata());
          this.withRedirectURI(instance.getRedirectURI());
          this.withRefreshToken(instance.getRefreshToken());
          this.withScopes(instance.getScopes());
          this.withUserName(instance.getUserName());
          this.withUserUID(instance.getUserUID());
          this.withApiVersion(instance.getApiVersion());
          this.withAuthorizeToken(instance.getAuthorizeToken());
          this.withClientName(instance.getClientName());
          this.withExpiresIn(instance.getExpiresIn());
          this.withInactivityTimeoutSeconds(instance.getInactivityTimeoutSeconds());
          this.withKind(instance.getKind());
          this.withMetadata(instance.getMetadata());
          this.withRedirectURI(instance.getRedirectURI());
          this.withRefreshToken(instance.getRefreshToken());
          this.withScopes(instance.getScopes());
          this.withUserName(instance.getUserName());
          this.withUserUID(instance.getUserUID());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion = apiVersion;
    return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public String getAuthorizeToken() {
    return this.authorizeToken;
  }
  
  public A withAuthorizeToken(String authorizeToken) {
    this.authorizeToken = authorizeToken;
    return (A) this;
  }
  
  public boolean hasAuthorizeToken() {
    return this.authorizeToken != null;
  }
  
  public String getClientName() {
    return this.clientName;
  }
  
  public A withClientName(String clientName) {
    this.clientName = clientName;
    return (A) this;
  }
  
  public boolean hasClientName() {
    return this.clientName != null;
  }
  
  public Long getExpiresIn() {
    return this.expiresIn;
  }
  
  public A withExpiresIn(Long expiresIn) {
    this.expiresIn = expiresIn;
    return (A) this;
  }
  
  public boolean hasExpiresIn() {
    return this.expiresIn != null;
  }
  
  public Integer getInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds;
  }
  
  public A withInactivityTimeoutSeconds(Integer inactivityTimeoutSeconds) {
    this.inactivityTimeoutSeconds = inactivityTimeoutSeconds;
    return (A) this;
  }
  
  public boolean hasInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind = kind;
    return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public ObjectMeta buildMetadata() {
    return this.metadata != null ? this.metadata.build() : null;
  }
  
  public A withMetadata(ObjectMeta metadata) {
    this._visitables.remove(this.metadata);
    if (metadata != null) {
        this.metadata = new ObjectMetaBuilder(metadata);
        this._visitables.get("metadata").add(this.metadata);
    } else {
        this.metadata = null;
        this._visitables.get("metadata").remove(this.metadata);
    }
    return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  
  public MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MetadataNested(item);
  }
  
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ObjectMetaBuilder().build()));
  }
  
  public MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  
  public String getRedirectURI() {
    return this.redirectURI;
  }
  
  public A withRedirectURI(String redirectURI) {
    this.redirectURI = redirectURI;
    return (A) this;
  }
  
  public boolean hasRedirectURI() {
    return this.redirectURI != null;
  }
  
  public String getRefreshToken() {
    return this.refreshToken;
  }
  
  public A withRefreshToken(String refreshToken) {
    this.refreshToken = refreshToken;
    return (A) this;
  }
  
  public boolean hasRefreshToken() {
    return this.refreshToken != null;
  }
  
  public A addToScopes(int index,String item) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    this.scopes.add(index, item);
    return (A)this;
  }
  
  public A setToScopes(int index,String item) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    this.scopes.set(index, item); return (A)this;
  }
  
  public A addToScopes(java.lang.String... items) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    for (String item : items) {this.scopes.add(item);} return (A)this;
  }
  
  public A addAllToScopes(Collection<String> items) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    for (String item : items) {this.scopes.add(item);} return (A)this;
  }
  
  public A removeFromScopes(java.lang.String... items) {
    if (this.scopes == null) return (A)this;
    for (String item : items) { this.scopes.remove(item);} return (A)this;
  }
  
  public A removeAllFromScopes(Collection<String> items) {
    if (this.scopes == null) return (A)this;
    for (String item : items) { this.scopes.remove(item);} return (A)this;
  }
  
  public List<String> getScopes() {
    return this.scopes;
  }
  
  public String getScope(int index) {
    return this.scopes.get(index);
  }
  
  public String getFirstScope() {
    return this.scopes.get(0);
  }
  
  public String getLastScope() {
    return this.scopes.get(scopes.size() - 1);
  }
  
  public String getMatchingScope(Predicate<String> predicate) {
      for (String item : scopes) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingScope(Predicate<String> predicate) {
      for (String item : scopes) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withScopes(List<String> scopes) {
    if (scopes != null) {
        this.scopes = new ArrayList();
        for (String item : scopes) {
          this.addToScopes(item);
        }
    } else {
      this.scopes = null;
    }
    return (A) this;
  }
  
  public A withScopes(java.lang.String... scopes) {
    if (this.scopes != null) {this.scopes.clear(); _visitables.remove("scopes"); }
    if (scopes != null) {for (String item :scopes){ this.addToScopes(item);}} return (A) this;
  }
  
  public boolean hasScopes() {
    return this.scopes != null && !this.scopes.isEmpty();
  }
  
  public String getUserName() {
    return this.userName;
  }
  
  public A withUserName(String userName) {
    this.userName = userName;
    return (A) this;
  }
  
  public boolean hasUserName() {
    return this.userName != null;
  }
  
  public String getUserUID() {
    return this.userUID;
  }
  
  public A withUserUID(String userUID) {
    this.userUID = userUID;
    return (A) this;
  }
  
  public boolean hasUserUID() {
    return this.userUID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OAuthAccessTokenFluent that = (OAuthAccessTokenFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
    if (!java.util.Objects.equals(authorizeToken, that.authorizeToken)) return false;
    if (!java.util.Objects.equals(clientName, that.clientName)) return false;
    if (!java.util.Objects.equals(expiresIn, that.expiresIn)) return false;
    if (!java.util.Objects.equals(inactivityTimeoutSeconds, that.inactivityTimeoutSeconds)) return false;
    if (!java.util.Objects.equals(kind, that.kind)) return false;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
    if (!java.util.Objects.equals(redirectURI, that.redirectURI)) return false;
    if (!java.util.Objects.equals(refreshToken, that.refreshToken)) return false;
    if (!java.util.Objects.equals(scopes, that.scopes)) return false;
    if (!java.util.Objects.equals(userName, that.userName)) return false;
    if (!java.util.Objects.equals(userUID, that.userUID)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  authorizeToken,  clientName,  expiresIn,  inactivityTimeoutSeconds,  kind,  metadata,  redirectURI,  refreshToken,  scopes,  userName,  userUID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (authorizeToken != null) { sb.append("authorizeToken:"); sb.append(authorizeToken + ","); }
    if (clientName != null) { sb.append("clientName:"); sb.append(clientName + ","); }
    if (expiresIn != null) { sb.append("expiresIn:"); sb.append(expiresIn + ","); }
    if (inactivityTimeoutSeconds != null) { sb.append("inactivityTimeoutSeconds:"); sb.append(inactivityTimeoutSeconds + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (redirectURI != null) { sb.append("redirectURI:"); sb.append(redirectURI + ","); }
    if (refreshToken != null) { sb.append("refreshToken:"); sb.append(refreshToken + ","); }
    if (scopes != null && !scopes.isEmpty()) { sb.append("scopes:"); sb.append(scopes + ","); }
    if (userName != null) { sb.append("userName:"); sb.append(userName + ","); }
    if (userUID != null) { sb.append("userUID:"); sb.append(userUID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    ObjectMetaBuilder builder;
    
    public N and() {
      return (N) OAuthAccessTokenFluent.this.withMetadata(builder.build());
    }
    
    public N endMetadata() {
      return and();
    }
    
  
  }

}

==> openshift-model-6.9.2-sources.jar: io/fabric8/openshift/api/model/OAuthAccessTokenFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OAuthAccessTokenFluent<A extends OAuthAccessTokenFluent<A>> extends BaseFluent<A>{
  public OAuthAccessTokenFluent() {
  }
  
  public OAuthAccessTokenFluent(OAuthAccessToken instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private String authorizeToken;
  private String clientName;
  private Long expiresIn;
  private Integer inactivityTimeoutSeconds;
  private String kind;
  private ObjectMetaBuilder metadata;
  private String redirectURI;
  private String refreshToken;
  private List<String> scopes = new ArrayList<String>();
  private String userName;
  private String userUID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OAuthAccessToken instance) {
    instance = (instance != null ? instance : new OAuthAccessToken());
    if (instance != null) {
          this.withApiVersion(instance.getApiVersion());
          this.withAuthorizeToken(instance.getAuthorizeToken());
          this.withClientName(instance.getClientName());
          this.withExpiresIn(instance.getExpiresIn());
          this.withInactivityTimeoutSeconds(instance.getInactivityTimeoutSeconds());
          this.withKind(instance.getKind());
          this.withMetadata(instance.getMetadata());
          this.withRedirectURI(instance.getRedirectURI());
          this.withRefreshToken(instance.getRefreshToken());
          this.withScopes(instance.getScopes());
          this.withUserName(instance.getUserName());
          this.withUserUID(instance.getUserUID());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion = apiVersion;
    return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public String getAuthorizeToken() {
    return this.authorizeToken;
  }
  
  public A withAuthorizeToken(String authorizeToken) {
    this.authorizeToken = authorizeToken;
    return (A) this;
  }
  
  public boolean hasAuthorizeToken() {
    return this.authorizeToken != null;
  }
  
  public String getClientName() {
    return this.clientName;
  }
  
  public A withClientName(String clientName) {
    this.clientName = clientName;
    return (A) this;
  }
  
  public boolean hasClientName() {
    return this.clientName != null;
  }
  
  public Long getExpiresIn() {
    return this.expiresIn;
  }
  
  public A withExpiresIn(Long expiresIn) {
    this.expiresIn = expiresIn;
    return (A) this;
  }
  
  public boolean hasExpiresIn() {
    return this.expiresIn != null;
  }
  
  public Integer getInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds;
  }
  
  public A withInactivityTimeoutSeconds(Integer inactivityTimeoutSeconds) {
    this.inactivityTimeoutSeconds = inactivityTimeoutSeconds;
    return (A) this;
  }
  
  public boolean hasInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind = kind;
    return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public ObjectMeta buildMetadata() {
    return this.metadata != null ? this.metadata.build() : null;
  }
  
  public A withMetadata(ObjectMeta metadata) {
    this._visitables.remove("metadata");
    if (metadata != null) {
        this.metadata = new ObjectMetaBuilder(metadata);
        this._visitables.get("metadata").add(this.metadata);
    } else {
        this.metadata = null;
        this._visitables.get("metadata").remove(this.metadata);
    }
    return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  
  public MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MetadataNested(item);
  }
  
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ObjectMetaBuilder().build()));
  }
  
  public MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  
  public String getRedirectURI() {
    return this.redirectURI;
  }
  
  public A withRedirectURI(String redirectURI) {
    this.redirectURI = redirectURI;
    return (A) this;
  }
  
  public boolean hasRedirectURI() {
    return this.redirectURI != null;
  }
  
  public String getRefreshToken() {
    return this.refreshToken;
  }
  
  public A withRefreshToken(String refreshToken) {
    this.refreshToken = refreshToken;
    return (A) this;
  }
  
  public boolean hasRefreshToken() {
    return this.refreshToken != null;
  }
  
  public A addToScopes(int index,String item) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    this.scopes.add(index, item);
    return (A)this;
  }
  
  public A setToScopes(int index,String item) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    this.scopes.set(index, item); return (A)this;
  }
  
  public A addToScopes(java.lang.String... items) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    for (String item : items) {this.scopes.add(item);} return (A)this;
  }
  
  public A addAllToScopes(Collection<String> items) {
    if (this.scopes == null) {this.scopes = new ArrayList<String>();}
    for (String item : items) {this.scopes.add(item);} return (A)this;
  }
  
  public A removeFromScopes(java.lang.String... items) {
    if (this.scopes == null) return (A)this;
    for (String item : items) { this.scopes.remove(item);} return (A)this;
  }
  
  public A removeAllFromScopes(Collection<String> items) {
    if (this.scopes == null) return (A)this;
    for (String item : items) { this.scopes.remove(item);} return (A)this;
  }
  
  public List<String> getScopes() {
    return this.scopes;
  }
  
  public String getScope(int index) {
    return this.scopes.get(index);
  }
  
  public String getFirstScope() {
    return this.scopes.get(0);
  }
  
  public String getLastScope() {
    return this.scopes.get(scopes.size() - 1);
  }
  
  public String getMatchingScope(Predicate<String> predicate) {
      for (String item : scopes) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingScope(Predicate<String> predicate) {
      for (String item : scopes) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withScopes(List<String> scopes) {
    if (scopes != null) {
        this.scopes = new ArrayList();
        for (String item : scopes) {
          this.addToScopes(item);
        }
    } else {
      this.scopes = null;
    }
    return (A) this;
  }
  
  public A withScopes(java.lang.String... scopes) {
    if (this.scopes != null) {
        this.scopes.clear();
        _visitables.remove("scopes");
    }
    if (scopes != null) {
      for (String item : scopes) {
        this.addToScopes(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasScopes() {
    return this.scopes != null && !this.scopes.isEmpty();
  }
  
  public String getUserName() {
    return this.userName;
  }
  
  public A withUserName(String userName) {
    this.userName = userName;
    return (A) this;
  }
  
  public boolean hasUserName() {
    return this.userName != null;
  }
  
  public String getUserUID() {
    return this.userUID;
  }
  
  public A withUserUID(String userUID) {
    this.userUID = userUID;
    return (A) this;
  }
  
  public boolean hasUserUID() {
    return this.userUID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OAuthAccessTokenFluent that = (OAuthAccessTokenFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
    if (!java.util.Objects.equals(authorizeToken, that.authorizeToken)) return false;
    if (!java.util.Objects.equals(clientName, that.clientName)) return false;
    if (!java.util.Objects.equals(expiresIn, that.expiresIn)) return false;
    if (!java.util.Objects.equals(inactivityTimeoutSeconds, that.inactivityTimeoutSeconds)) return false;
    if (!java.util.Objects.equals(kind, that.kind)) return false;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
    if (!java.util.Objects.equals(redirectURI, that.redirectURI)) return false;
    if (!java.util.Objects.equals(refreshToken, that.refreshToken)) return false;
    if (!java.util.Objects.equals(scopes, that.scopes)) return false;
    if (!java.util.Objects.equals(userName, that.userName)) return false;
    if (!java.util.Objects.equals(userUID, that.userUID)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  authorizeToken,  clientName,  expiresIn,  inactivityTimeoutSeconds,  kind,  metadata,  redirectURI,  refreshToken,  scopes,  userName,  userUID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (authorizeToken != null) { sb.append("authorizeToken:"); sb.append(authorizeToken + ","); }
    if (clientName != null) { sb.append("clientName:"); sb.append(clientName + ","); }
    if (expiresIn != null) { sb.append("expiresIn:"); sb.append(expiresIn + ","); }
    if (inactivityTimeoutSeconds != null) { sb.append("inactivityTimeoutSeconds:"); sb.append(inactivityTimeoutSeconds + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (redirectURI != null) { sb.append("redirectURI:"); sb.append(redirectURI + ","); }
    if (refreshToken != null) { sb.append("refreshToken:"); sb.append(refreshToken + ","); }
    if (scopes != null && !scopes.isEmpty()) { sb.append("scopes:"); sb.append(scopes + ","); }
    if (userName != null) { sb.append("userName:"); sb.append(userName + ","); }
    if (userUID != null) { sb.append("userUID:"); sb.append(userUID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    ObjectMetaBuilder builder;
    
    public N and() {
      return (N) OAuthAccessTokenFluent.this.withMetadata(builder.build());
    }
    
    public N endMetadata() {
      return and();
    }
    
  
  }

}
